@@ -7,33 +7,29 @@ import json
 import pathlib
 
 DEFAULT_TRANSPORT = 'Symphony'
+DEFAULT_POLL_RETRY = 30
+DEFAULT_TIMEOUT = 60
+
 
 class AriaService:
     def __init__(self, base_url, session_id, **kwargs):
         self._base_url = base_url
         self._token = None
+        self._delta_token = None
+        self._paging_token = None
         self._session_id = session_id
         self._timeout_default = 30 if 'timeout' not in kwargs else int(kwargs['timeout'])
         self._headers = {'content-type':'application/json'}
 
-    def _process_aria_message(self, res, attribute=None):
-        try:
-            data = res.json()           #raises a ValueError if no valid json returned
-            if attribute is None:
-                if 'messages' in data:
-                    return data['messages']
-                elif 'message' in data:
-                    return data['message']
-                else:
-                    raise AriaError('No {} returned from server'.format(attribute), res)
-            if not data.get(attribute, None) and not data.get('detail', None):
-                raise AriaError('Unrecognised server response', res)
-            elif data['detail'].get(attribute, None):
-                return data['detail'][attribute]
+    def _process_aria_message(self, data, attribute=None):
+        if 'detail' in data:
+            detail = data['detail']
+            if attribute in detail:
+                return detail.get(attribute)
             else:
-                raise AriaError('Unrecognised server response', res)
-        except ValueError as ve:
-            raise AriaError(ve.args[0], res)
+                return detail
+        else:
+            raise AriaError('Unrecognised server response', data)
 
     def authenticate_app(self, key):
         token = self._authenticate('appKey', key)
@@ -54,16 +50,20 @@ class AriaService:
             headers={'content-type': 'application/json'}
         )
         res.raise_for_status()
-        return self._process_aria_message(res, 'token')
+        return self._process_aria_message(res.json(), 'token')
 
     def get_messages(self):
         res = requests.get(
             self._base_url+'/message',
             headers=self._headers,
-            timeout=self._timeout_default
+            timeout=self._timeout_default,
+            params={'deltaToken': self._delta_token, 'isSubscription': True}
         )
         res.raise_for_status()
-        return self._process_aria_message(res)
+        data = res.json()
+        if 'deltaToken' in data:
+            self._delta_token = data.get('deltaToken')
+        return self._process_aria_message(data)
 
     def search_messages(self, data, timeout=None, limit=1000):
         timeout = self._timeout_default if timeout is None else timeout
@@ -76,7 +76,7 @@ class AriaService:
             params={'limit': limit}
         )
         res.raise_for_status()
-        return self._process_aria_message(res)
+        return self._process_aria_message(res.json())
 
     def send_message(self, channel, raw_message, **kwargs):
         message = {"channel": channel, "payload": {}}
@@ -114,7 +114,7 @@ class AriaService:
             timeout=self._timeout_default
         )
         res.raise_for_status()
-        return self._process_aria_message(res)
+        return self._process_aria_message(res.json())
 
     def who_am_i(self):
         res = requests.get(
@@ -123,7 +123,7 @@ class AriaService:
             timeout=self._timeout_default
         )
         res.raise_for_status()
-        return self._process_aria_message(res)
+        return self._process_aria_message(res.json(), 'email')
 
     def get_connections(self):
         res = requests.get(
@@ -132,7 +132,7 @@ class AriaService:
             timeout=self._timeout_default
         )
         res.raise_for_status()
-        return self._process_aria_message(res)
+        return self._process_aria_message(res.json())
 
     def add_connection(self, user, accept=None):
         data = {"user": user}
@@ -148,7 +148,7 @@ class AriaService:
             timeout=self._timeout_default
         )
         res.raise_for_status()
-        return self._process_aria_message(res)
+        return self._process_aria_message(res.json())
 
     def get_room_details(self, room_id, id_type='id', limit=1):
         params = { id_type: room_id, 'limit': limit }
@@ -163,7 +163,7 @@ class AriaService:
         else:
             res.raise_for_status()
 
-        return self._process_aria_message(res)
+        return self._process_aria_message(res.json())
 
     def create_room(self, room_name, room_description):
         res = requests.post(
@@ -173,7 +173,7 @@ class AriaService:
             timeout=self._timeout_default
         )
         res.raise_for_status()
-        return self._process_aria_message(res)
+        return self._process_aria_message(res.json())
 
     '''Display all members of a room'''
     def get_room_members(self, room_name, **kwargs):
@@ -191,7 +191,7 @@ class AriaService:
             raise AriaError('Room {0} not found'.format(room_name), res)
         else:
             res.raise_for_status()
-        return self._process_aria_message(res)
+        return self._process_aria_message(res.json())
 
     '''Add a member or list of members to a room'''
     def add_room_members(self, room_name, member_email, **kwargs):
@@ -216,7 +216,7 @@ class AriaService:
             raise AriaError('Room {0} not found'.format(room_name), res)
         else:
             res.raise_for_status()
-        return self._process_aria_message(res)
+        return self._process_aria_message(res.json())
 
     '''Remove a member or list of members from a room'''
     def remove_room_members(self, room_name, member_email, **kwargs):
@@ -241,7 +241,7 @@ class AriaService:
             raise AriaError('Room {0} not found'.format(room_name), res)
         else:
             res.raise_for_status()
-        return self._process_aria_message(res)
+        return self._process_aria_message(res.json())
 
     def download_file(self, url, local_filename=None):
         if not local_filename:
