@@ -85,16 +85,18 @@ class AriaBot:
                 except AttributeError as ae:
                     logging.warning('{} - ignoring entity'.format(ae.args[0], _ent['class']))
 
-    def _process_text(self, channel, msg, msg_text):
+    def _process_message(self, channel, msg, attachments, msg_text):
         processed = False
         start = 0
         item = 1
+        if not isinstance(attachments, list):
+            attachments = None
         while start < len(msg_text):
             cmd, cmd_match = AriaBotCommand.match_command(msg_text, start)
             if not cmd_match:
                 break
             processed = True
-            cmd.do(match=cmd_match, message=msg, index=item, channel=channel)
+            cmd.do(match=cmd_match, message=msg, index=item, attachments=attachments, channel=channel)
             start = cmd_match.span()[1] + 1
             item = item + 1
         return processed
@@ -136,8 +138,6 @@ class AriaBot:
         if not CONFIG_REQUIRED.issubset(list(self.env.keys())):
             raise AriaBotException('Missing required attribute from: '+str(CONFIG_REQUIRED))
 
-        app_credentials = None if 'app_credentials' not in self.env else self.env['app_credentials']
-
         cer = None
         try:
             cer = AriaService.read_cert(self.env['cert'])
@@ -170,7 +170,9 @@ class AriaBot:
                     #    continue
 
                     logging.debug('Msg: {}'.format(str(msg)))
-
+                    # Ignore everything except actual messages, or anonymous
+                    if msg['type'] != 'MESSAGE_SENT' or 'email' not in msg['sender']:
+                        continue
                     from_email = msg['sender']['email']
                     # if this message is from the bot skip to next message.
                     if from_email == self.session:
@@ -181,7 +183,7 @@ class AriaBot:
                     if 'channel' in msg:
                         channel = msg['channel']['name']
                     payload = msg['payload']
-                    processed_text = self._process_text(channel, payload.get('message',''), msg_text)
+                    processed_text = self._process_message(channel, payload.get('message', ''), msg['attachments'], msg_text)
                     processed_entities = False
                     if 'data' in payload:
                         data = json.loads(payload['data'])
@@ -195,7 +197,7 @@ class AriaBot:
                 if msg is not None:
                     err_msg = SymphonyMessageML()
                     err_msg.root().text = '🤖 [{}]'.format(ex.args[0])
-                    self.aria.send_message(msg['channel'], err_msg)
+                    self.aria.send_message(channel, err_msg)
 
             except (KeyboardInterrupt, SystemExit) as exiting:
                 logging.error('Exiting: {}'.format(exiting))
@@ -215,7 +217,7 @@ class AriaBot:
                     if channel is not None:
                         err_msg = SymphonyMessageML()
                         err_msg.root().text = '🤖 [{}]'.format(msg_text)
-                        self.aria.send_message(msg['channel'], err_msg)
+                        self.aria.send_message(channel, err_msg)
                     sleep(poll_retry)
 
             except ConnectionError as ce:
